/**
* Copyright (c) 2005, Freescale Semiconductor
* Freescale Willy Note
*
* File name : main.c
* Project name: ICS_QG8.mcp
*
* Author : Sergio Garca de Alba Garcin
*          Gonzalo Delgado Huitron
* Department : RTAC Americas
*
* Description : This example illustrates the use of the ICS module for the 
*               MC9S08QG8 microcontroller. It is assumed that for the external 
*               oscillator a 4.9152 MHz crystal is being used. Reseting the 
*               board after programming FBI or FBILP modes is suggested to 
*               assure fast programming. This project was made with the Device 
*               Initialization tool which sets the module, according to the 
*               user's needs. For this example, the ICS module is configured 
*               to comply with the following requirements:
*                       + COP is disabled 
*
*                            
* (Refer to AN3136 for more information about Device Initialization)
*
* History :   
* 10/08/2005  : Release (rgd04c)
*/


#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */
#include "MCUinit.h"

/* It is assumed that for the external oscillator a 4.9152 MHz crystal is being used */
/* */

/* Uncomment the desired mode */

//#define FEI		  /* led blinks every 2 secs (16MHz div 2 div 2 div 128 div 65536 */
//#define FEE		  /* led blinks every 1.7 sec (4.9152MHz div 128 mul 512 div 2 div 2 div 128 div 65536 */
//#define FBI		  /* led blinks every 8 sec (32,768 div 2 div 2 div 65536 */
#define FBILP		  /* led blinks every 4 sec (32,768 div 1 div 2 div 65536 */
//#define FBE   	  /* led blinks every 6.8 sec (4.9152MHz div 2 div 2 div 128 div 65536 */
//#define FBELP		  /* led blinks every 3.4 sec (4.9152MHz div 1 div 2 div 128 div 65536 */

void ICSinit(void);

void main(void) {
 // MCU_init();
  EnableInterrupts;    /* enable interrupts */
 
 ICSinit();			  /* initialize ICS */
 
 TPMSC=0x0F;		  /* bus clk as the TPM source, divide by 128 */
 TPMC1SC=0x14; 		  /* toggle output on compare (TPM channel 1, PTB5)*/
 
 #ifdef FBI
 TPMSC=0x08;	  	  /* bus clk as the TPM source, divide by 1 */
 #endif

 #ifdef FBILP
 TPMSC=0x08;	  	  /* bus clk as the TPM source, divide by 1 */
 #endif



  for(;;) {
  } /* loop forever */
  /* please make sure that you never leave this function */
}

void ICSinit(){
 
 #ifdef FEI
            		  /* this is the default ICS operating mode, ICSC1 and ICSC2 only need to be programmed */
					  /* if you want to change the default configuration */
 #endif
 
 #ifdef FEE
 ICSC1= 0x38;		  /* CLKS for Output of FLL, RDIV divide by 128, IREFS for external reference */
 ICSC2= 0x64;         /* RANGE for high freq range, HGO for low power, EREFS for oscillator requested */
 while(ICSSC_OSCINIT==0);   /* wait for the initialization cycles of the external crystal to complete */
 #endif
 
 #ifdef FBI
 ICSC1= 0x44;		  /* CLKS for Internal reference clock, IREFS for internal reference */
 ICSC2= 0x40; 		  /* everything as default */
 #endif
 
 #ifdef FBILP
 ICSC1= 0x44;		  /* CLKS for Internal reference clock, IREFS for internal reference */
 ICSC2= 0x08; 		  /* BDIV divide by 1, LP for FLL disabled */
 #endif
 
 #ifdef FBE
 ICSC1= 0xB8;		  /* CLKS for External reference clock, IREFS for external reference */
 ICSC2= 0x74;         /* RANGE for high freq range, HGO for low power, EREFS for oscillator requested */
 while(ICSSC_OSCINIT==0);   /* wait for the initialization cycles of the external crystal to complete */
 #endif
 
 #ifdef FBELP
 ICSC1= 0x80;		  /* CLKS for External reference clock, IREFS for external reference */
 ICSC2= 0x2C;         /* BDIV divide by 1, RANGE for high freq range, HGO for low power, */ 
                      /* EREFS for oscillator requested, LP for FLL disabled */
 while(ICSSC_OSCINIT==0);   /* wait for the initialization cycles of the external crystal to complete */
 #endif
 
}

