/**
* Copyright (c) 2005, Freescale Semiconductor
* Freescale Willy Note
*
* File name : main.c
* Project name: TPM_OC_QG8.mcp
*
* Author : Laura Delgado
* Department : RTAC Americas
*
* Description : This example illustrates the use of the TPM module in the MS9S08QG8 
*               microcontroller. This example makes use of the Device Initialization 
*               tool for the Timer module set up. 
*               
*               For this example, the TPM (Timer/PWM) module is configured
*               to comply with the following requirements:
*                       + Timer configured as output compare, to toggle the 
*                           output (TPM0) when counter reaches compare value 
*                           0X0FFF.
*                           
*                       + Counter frequency at 3.81 Hz (bus clock selected as
*                           clock source, prescale value of 32, modulo counter 
*                           at 0x7FFF)
*                           
*                       + The selected channel output pin is PTA0/TPMCH0 and
*                           has no pull resistor.
*                       
*                       + Both, overflow and channel interrupts are enabled 
*                           to toggle a LED when their corresponding ISR 
*                           is serviced.
*                       
*                       +  PTB6 and PTB7 are initialized as outputs to control
*                            the LEDs                         
*                                                       
*               The initialization of the module is the Device Initialization tool 
*               automatically generated MCUinit.c code, which was included in this 
*               project.
*
*               This example was explicitly made for the MC9S08QG8 microcontroller 
*               migrating may need some changes in the code.
*           
*               (Refer to AN3136 for more information about Device Initialization)
* History :   
* 10/08/2005  : Release (r12370c)
*/

#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */
#include "MCUinit.h"



void main(void) {

  MCU_init();

  for(;;) {
  } /* loop forever */
}
 


void interrupt 5 Vtpmch0_ISR (void) {

    TPMC0SC_CH0F = 0;   // ACK channel interrupt 
                        // Reading flag, then write a zero to the bit. 
    
    PTBD_PTBD6 = ~PTBD_PTBD6;

}

void interrupt 7 Vtpmovf_ISR(void){

    TPMSC_TOF = 0;      // ACK timer overflow interrupt 
                        // Reading flag, then write a zero to the bit. 

    
    PTBD_PTBD7 = ~PTBD_PTBD7;

}